Documentation
¶
Index ¶
- func Asset(name string) ([]byte, error)
- func AssetDir(name string) ([]string, error)
- func AssetInfo(name string) (os.FileInfo, error)
- func AssetNames() []string
- func GoToHadoopType(gt string) string
- func GoToJavaType(gt string) string
- func GoToValueInHadoopType(gt string) string
- func MustAsset(name string) []byte
- func RestoreAsset(dir, name string) error
- func RestoreAssets(dir, name string) error
- type Func
- type Generator
- type Initializer
- type Interface
- type Method
- type Package
- type Param
- type Struct
- type Target
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Asset ¶
Asset loads and returns the asset for the given name. It returns an error if the asset could not be found or could not be loaded.
func AssetDir ¶
AssetDir returns the file names below a certain directory embedded in the file by go-bindata. For example if you run go-bindata on data/... and data contains the following hierarchy:
data/
foo.txt
img/
a.png
b.png
then AssetDir("data") would return []string{"foo.txt", "img"} AssetDir("data/img") would return []string{"a.png", "b.png"} AssetDir("foo.txt") and AssetDir("notexist") would return an error AssetDir("") will return []string{"data"}.
func AssetInfo ¶
AssetInfo loads and returns the asset info for the given name. It returns an error if the asset could not be found or could not be loaded.
func GoToHadoopType ¶
GoToHadoopType converts the given go type into its corresponding MapReduce type.
func GoToJavaType ¶
GoToJavaType converts the given go type into its corresponding Java type.
func GoToValueInHadoopType ¶
func MustAsset ¶
MustAsset is like Asset but panics when Asset would return an error. It simplifies safe initialization of global variables.
func RestoreAsset ¶
RestoreAsset restores an asset under the given directory
func RestoreAssets ¶
RestoreAssets restores an asset under the given directory recursively
Types ¶
type Generator ¶
type Generator struct {
// contains filtered or unexported fields
}
Generator holds the state of the analysis. Primarily used to buffer the output for format.Source.
func NewGenerator ¶
NewGenerator creates a new Generator, ready for use.
type Initializer ¶
type Initializer struct {
// contains filtered or unexported fields
}
func NewInitializer ¶
func NewInitializer(dir string) *Initializer
func (*Initializer) CollectConfig ¶
func (i *Initializer) CollectConfig(out io.Writer, in io.Reader)
func (*Initializer) Initialize ¶
func (i *Initializer) Initialize()
type Interface ¶
type Interface struct {
// contains filtered or unexported fields
}
func NewInterface ¶
type Package ¶
type Package struct {
// contains filtered or unexported fields
}
A Package contains information about a given Package.
Source Files
¶
Directories
¶
| Path | Synopsis |
|---|---|
|
Gomrnative is a tool to automate the boilerplate generation of Java code necessary to natively interact with Hadoop MapReduce.
|
Gomrnative is a tool to automate the boilerplate generation of Java code necessary to natively interact with Hadoop MapReduce. |